@@ -6,7 +6,7 @@ App::Mypp - Maintain Your Perl Project
 
 =head1 VERSION
 
-0.05_01
+0.03
 
 =head1 DESCRIPTION
 
@@ -26,10 +26,6 @@ anything, so 1) it just works 2) it might not work as you want it to.
   * Create/update t/00-load.t and t/99-pod*t
   * Create/update README
 
- -test
-  * Create/update t/00-load.t and t/99-pod*t
-  * Test the project
-
  -build
   * Same as -update
   * Update Changes with release date
@@ -41,6 +37,10 @@ anything, so 1) it just works 2) it might not work as you want it to.
   * Push commit and tag to "origin"
   * Upload the disted file to CPAN
 
+ -test
+  * Create/update t/00-load.t and t/99-pod*t
+  * Test the project
+
  -clean
   * Remove files and directories which should not be included
     in the project repo
@@ -48,9 +48,6 @@ anything, so 1) it just works 2) it might not work as you want it to.
  -makefile
   * Create a Makefile.PL from plain guesswork
 
- -version
-  * Display the version number for for mypp
-
  -man
   * Display manual for mypp
 
@@ -124,7 +121,7 @@ use File::Basename;
 use File::Find;
 use YAML::Tiny;
 
-our $VERSION = '0.05_01';
+our $VERSION = '0.03';
 our $SILENT = $ENV{'SILENT'} || 0;
 our $MAKEFILE_FILENAME = 'Makefile.PL';
 our $CHANGES_FILENAME = 'Changes';
@@ -570,24 +567,24 @@ sub _pm_requires {
             push @modules, $module if(caller(0) eq $required_module);
         }, @INC);
 
-        eval "use $required_module (); 1" or warn $@;
+        require $file or warn $@;
         return if($@);
     }
 
     if(my $meta = eval "$required_module\->meta") {
         if($meta->isa('Class::MOP::Class')) {
-            push @modules, $meta->superclasses, map { split /\|/, $_->name } @{ $meta->roles };
+            push @modules, $meta->superclasses, map { $_->name } @{ $meta->roles };
         }
         else {
-            push @modules, map { split /\|/, $_->name } @{ $meta->get_roles };
+            push @modules, map { $_->name } @{ $meta->get_roles };
         }
     }
     else {
         push @modules, eval "\@$required_module\::ISA";
     }
 
-    for my $m (@modules) {
-        my($module, $version) = $self->_version_from_module($m) or next;
+    for my $module (@modules) {
+        my $version = $self->_version_from_module($module) or next;
         $requires->{$module} = $version;
     }
 
@@ -622,10 +619,9 @@ sub _script_requires {
         }
     }
 
-    for my $m (@$modules) {
-        local $SIG{'__WARN__'} = sub { print $_[0] unless($_[0] =~ /\sredefined\sat/)};
-        eval "use $m (); 1" or warn $@;
-        my($module, $version) = $self->_version_from_module($m) or next;
+    for my $module (@$modules) {
+        eval "require $module";
+        my $version = $self->_version_from_module($module) or next;
         $requires->{$module} = $version;
     }
 
@@ -643,7 +639,7 @@ sub manifest {
 
     open my $SKIP, '>', 'MANIFEST.SKIP' or die "Write 'MANIFEST.SKIP': $!\n";
     print $SKIP "$_\n" for qw(
-                           ^mypp.yml
+                           ^dperl.yml
                            .git
                            \.old
                            \.swp
@@ -680,7 +676,7 @@ Will commit with the text from Changes and create a tag
 
 sub tag_and_commit {
     my $self = shift;
-    $self->_vsystem(git => commit => -a => -m => $self->changes->{'text'});
+    $self->_vsystem(git => commit => -a => -m => $self->changes->{'latest'});
     $self->_vsystem(git => tag => $self->changes->{'version'});
     return 1;
 }
@@ -830,7 +826,7 @@ sub help {
 sub _vsystem {
     shift; # shift off class/object
     print "\$ @_\n" unless $SILENT;
-    return $SILENT ? system "@_ 1>/dev/null 2>/dev/null" : system @_;
+    system @_;
 }
 
 sub _filename_to_module {
@@ -846,13 +842,11 @@ sub _version_from_module {
     my $module = shift;
 
     while($module) {
-        if(my $version = eval "\$$module\::VERSION") {
-            return($module, $version);
-        }
+        return $_ if($_ = eval "\$$module\::VERSION");
         $module =~ s/::\w+$// or last;
     }
 
-    return;
+    return 0;
 }
 
 =head1 SEE ALSO
